Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(325)

Unified Diff: third_party/WebKit/public/web/WebWidgetClient.h

Issue 1879103002: Convert main-thread overscroll parameters into viewport space. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/public/web/WebWidgetClient.h
diff --git a/third_party/WebKit/public/web/WebWidgetClient.h b/third_party/WebKit/public/web/WebWidgetClient.h
index 6497e9133e47621be7ba6d212929b2fb0cd5ac50..849a3d097d0a705b3bf16fe22638410d91fd4a9c 100644
--- a/third_party/WebKit/public/web/WebWidgetClient.h
+++ b/third_party/WebKit/public/web/WebWidgetClient.h
@@ -133,8 +133,13 @@ public:
// Called when a gesture event is handled.
virtual void didHandleGestureEvent(const WebGestureEvent& event, bool eventCancelled) { }
- // Called when overscrolled on main thread.
- virtual void didOverscroll(const WebFloatSize& unusedDelta, const WebFloatSize& accumulatedRootOverScroll, const WebFloatPoint& position, const WebFloatSize& velocity) { }
+ // Called when overscrolled on main thread. All parameters are in
+ // viewport-space.
+ virtual void didOverscroll(
+ const WebFloatSize& overscrollDelta,
+ const WebFloatSize& accumulatedOverscroll,
+ const WebFloatPoint& positionInViewport,
+ const WebFloatSize& velocityInViewport) { }
// Called to update if touch events should be sent.
virtual void hasTouchEventHandlers(bool) { }

Powered by Google App Engine
This is Rietveld 408576698